from kitmaioog.cyphertext import cyphertext

use = cyphertext()

print("-" * 20, "Secret", "-" * 20)
print("1.Encode")
print("2.Decode")
print("-" * 48)
menu = input("Select Menu : ")

if menu == "1" :
    use.encode()
elif menu == "2" :
    use.decode()



list = []
class cyphertext :
    def __innit__(self) :
        pass
    def encode(self) :
        list = []
        text = input("Enter your text : ")
        for encode in text :
            list.append(ord(encode))
        for e in list :
            data = str(chr(e+1))
            print(data, end="")
    def decode(self) :
        list = []
        text = input("Enter your cyphertext : ")
        for decode in text :
            list.append(ord(decode))
        for n in list :
            data = str(chr(n-1))
            print(data, end="")